@@ -322,19 +322,10 @@ int find_landing_plane(Vector car_location, Vector car_velocity, double gravity)
     }
 };
 
-struct jump_viable_dat
+_Bool jump_is_viable(double T, double boost_accel, double distance, Vector direction, Vector car_forward, int car_boost, double car_speed)
 {
-    _Bool forward;
-    _Bool backward;
-};
-
-struct jump_viable_dat jump_is_viable(double T, double boost_accel, double distance, Vector direction, Vector car_forward, int car_boost, double car_speed)
-{
-    struct jump_viable_dat r;
-
     if (multiply(direction, double_to_vector(distance)).z > 300) {
-        r.forward = r.backward = 0;
-        return r;
+        return 0;
     }
 
     double forward_angle = angle(flatten(direction), flatten(car_forward));
@@ -346,10 +337,10 @@ struct jump_viable_dat jump_is_viable(double T, double boost_accel, double dista
     double forward_time = T - forward_turn_time;
     double backward_time = T - backward_turn_time;
 
-    r.forward = forward_time > 0 && forward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(forward_turn_time, car_speed), car_boost);
-    r.backward = backward_time > 0 && distance < 1500 && backward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(backward_turn_time, car_speed), 0);
+    _Bool forward = forward_time > 0 && forward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(forward_turn_time, car_speed), car_boost);
+    _Bool backward = backward_time > 0 && distance < 1500 && backward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(backward_turn_time, car_speed), 0);
 
-    return r;
+    return forward || backward;
 }
 
 struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double boost_accel, double car_speed)
@@ -368,16 +359,8 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, do
         Vector right_vector = normalize(sub(r.targets.right, ball_location)).vector;
         r.best_shot_vector = clamp(direction, left_vector, right_vector);
 
-        if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
-        {
-            double slope = find_slope(r.best_shot_vector, car_to_ball);
-            if (slope > 0) {
-                struct jump_viable_dat is_viable = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
-
-                if (is_viable.forward || (is_viable.backward && slope > 0.5))
-                    r.found = 1;
-            }
-        }
+        if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(r.best_shot_vector, car_to_ball) > 0.5)
+            r.found = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
     }
 
     return r;
@@ -394,15 +377,8 @@ struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_sh
 
     r.best_shot_vector = direction;
 
-    if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
-    {
-        double slope = find_slope(r.best_shot_vector, car_to_ball);
-        if (slope > 0) {
-            struct jump_viable_dat is_viable = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
-            if (is_viable.forward || (is_viable.backward && slope > 0.5))
-                r.found = 1;
-        }
-    }
+    if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(r.best_shot_vector, car_to_ball) > 0.5)
+        r.found = jump_is_viable(time_remaining, boost_accel, car_to_ball_norm.magnitude, direction, car_forward, car_boost, car_speed);
 
     return r;
 };
@@ -509,7 +485,7 @@ struct ground_shot parse_slice_for_ground_shot_with_target(double time_remaining
         Vector right_vector = normalize(sub(r.targets.right, ball_location)).vector;
         Vector best_shot_vector = clamp2D(direction, left_vector, right_vector);
 
-        if (in_field(sub(ball_location, multiply(best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(best_shot_vector, car_to_ball) > 0)
+        if (in_field(sub(ball_location, multiply(best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(best_shot_vector, car_to_ball) > 0.5)
             r.found = ground_shot_is_viable(time_remaining, me.hitbox, boost_accel, car_to_ball_norm.magnitude, direction, me.forward, me.boost, magnitude(me.velocity));
     }
 
@@ -527,7 +503,7 @@ struct ground_shot parse_slice_for_ground_shot(double time_remaining, double bes
 
     Vector best_shot_vector = direction;
 
-    if (in_field(sub(ball_location, multiply(best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(best_shot_vector, car_to_ball) > 0)
+    if (in_field(sub(ball_location, multiply(best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(best_shot_vector, car_to_ball) > 0.5)
         r.found = ground_shot_is_viable(time_remaining, me.hitbox, boost_accel, car_to_ball_norm.magnitude, direction, me.forward, me.boost, magnitude(me.velocity));
 
     return r;
@@ -722,9 +698,9 @@ static PyObject *method_jump_shot_is_viable(PyObject *self, PyObject *args)
     if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)id", &time_remaining, &boost_accel, &distance, &direction.x, &direction.y, &direction.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &car_speed))
         return NULL;
 
-    struct jump_viable_dat shot_viable = jump_is_viable(time_remaining, boost_accel, distance, direction, car_forward, car_boost, car_speed);
+    _Bool shot_viable = jump_is_viable(time_remaining, boost_accel, distance, direction, car_forward, car_boost, car_speed);
 
-    return (shot_viable.forward || shot_viable.backward) ? Py_True : Py_False;
+    return (shot_viable) ? Py_True : Py_False;
 }
 
 static PyObject *method_parse_slice_for_double_jump_with_target(PyObject *self, PyObject *args)
